# Automatic exposure script
# Sets the selected VRayPhysicalCamera's exposure value according to the maximum value of a specified VRayLightMeter shape node.
# Automatic ISO - this variant does not modify apaerture (A), not shutther speed (S), but adjusts the ISO instead.
import math
import maya.cmds as cmds
import maya.mel as mel

# The name of the light meter shape node
lightMeter = "VRayLightMeterShape1"

# Get the highest value from the light meter
lux = mel.eval("vray getLightmeterMaxValue " + lightMeter + " total")

# Get the cameras A, S and ISO
ISO = cmds.getAttr(".vrayCameraPhysicalISO") 
A = cmds.getAttr(".vrayCameraPhysicalFNumber") 
S = cmds.getAttr(".vrayCameraPhysicalShutterSpeed") 

# Calculating EV for the illuminance (lux) at ISO = 100:
# lux = (2 ^ EV) * 2.5;
# EV = log2 A^2/5
EV = math.log((lux[0] / 2.5), 2)

# Iso Correction
EVc = EV + math.log((ISO/100), 2)

# Using Shutter Speed as intermediary for the new ISO calculation
Sc = math.pow(2, EVc) / math.pow(A, 2)

# Calculate and set the new ISO
cmds.setAttr (".vrayCameraPhysicalISO", ISO * (S / Sc))